@@ -562,7 +562,6 @@ static void
 kz_gecko_embed_class_init (KzGeckoEmbedClass *klass)
 {
 	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	GtkMozEmbedClass *moz_embed_class;
 
@@ -662,7 +661,6 @@ constructor (GType                  type,
 {
 	GObject *object;
 	GObjectClass *klass = G_OBJECT_CLASS(kz_gecko_embed_parent_class);
-	gchar *title;
 
 	object = klass->constructor(type, n_props, props);
 	
@@ -819,7 +817,6 @@ kz_gecko_embed_load_url (KzEmbed *kzembed, const gchar *url)
 
 	g_return_if_fail(KZ_IS_GECKO_EMBED(kzembed));
 
-	KzGeckoEmbed *mozembed = KZ_GECKO_EMBED(kzembed);
 	KzGeckoEmbedPrivate *priv = KZ_GECKO_EMBED_GET_PRIVATE (kzembed);
 
 	if (url && *url)
@@ -1715,7 +1712,6 @@ kz_gecko_embed_highlight_word (KzEmbed *kzembed, const char *word)
 
 	const PRUnichar span[]          = { 's', 'p', 'a', 'n' ,'\0' };
 	const PRUnichar style[]         = { 's', 't', 'y', 'l' ,'e', '\0' };
-	const PRUnichar u_color[]       = { 's', 'p', 'a', 'n' ,'\0' };
 	const PRUnichar id[]            = { 'i', 'd', '\0' };
 	const PRUnichar sc[]            = { ';', '\0' };
 	const PRUnichar bg_color[]      = { 'b', 'a', 'c', 'k' ,'g', 'r', 
@@ -1969,7 +1965,6 @@ kz_gecko_embed_selection_is_collapsed (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_GECKO_EMBED(kzembed), TRUE);
 
-	KzGeckoEmbed *mozembed = KZ_GECKO_EMBED(kzembed);
 	KzGeckoEmbedPrivate *priv = KZ_GECKO_EMBED_GET_PRIVATE (kzembed);
 	if (!priv->wrapper) return TRUE;
 
@@ -1992,7 +1987,6 @@ kz_gecko_embed_get_links (KzEmbed *kzembed, GList **list,
 			gboolean selected_only)
 {
 	g_return_val_if_fail(KZ_IS_GECKO_EMBED(kzembed), FALSE);
-	KzGeckoEmbed *mozembed = KZ_GECKO_EMBED(kzembed);
 	KzGeckoEmbedPrivate *priv = KZ_GECKO_EMBED_GET_PRIVATE (kzembed);
 	g_return_val_if_fail(priv->wrapper, FALSE);
 	g_return_val_if_fail(list, FALSE);
@@ -2026,7 +2020,6 @@ static gboolean
 kz_gecko_embed_get_dest_anchors (KzEmbed *kzembed, GList **list)
 {
 	g_return_val_if_fail(KZ_IS_GECKO_EMBED(kzembed), FALSE);
-	KzGeckoEmbed *mozembed = KZ_GECKO_EMBED(kzembed);
 	KzGeckoEmbedPrivate *priv = KZ_GECKO_EMBED_GET_PRIVATE (kzembed);
 	g_return_val_if_fail(priv->wrapper, FALSE);
 	g_return_val_if_fail(list, FALSE);
@@ -2373,6 +2366,9 @@ kz_gecko_embed_reload (KzEmbed *kzembed, KzEmbedReloadFlag flags)
 	  case KZ_EMBED_RELOAD_CHARSET_CHANGE:
 	    moz_flags = GTK_MOZ_EMBED_FLAG_RELOADCHARSETCHANGE;
 	    break;
+	  default:
+	    moz_flags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
+	    break;
 	}
 
 	gtk_moz_embed_reload(GTK_MOZ_EMBED(kzembed), moz_flags);
@@ -2473,7 +2469,7 @@ kz_gecko_embed_set_nth_nav_link (KzEmbed *kzembed,
 
 	if (n >= len)
 	{
-		int i;
+		guint i;
 		for (i = len; i < n; i++)
 		{
 			priv->nav_links[link] =
@@ -2601,7 +2597,6 @@ kz_gecko_embed_shistory_get_nth (KzEmbed *kzembed,
 {
 	g_return_if_fail(KZ_IS_GECKO_EMBED(kzembed));
 
-	KzGeckoEmbed *mozembed = KZ_GECKO_EMBED(kzembed);
 	KzGeckoEmbedPrivate *priv = KZ_GECKO_EMBED_GET_PRIVATE (kzembed);
 	KzMozWrapper *wrapper = priv->wrapper;
 	nsresult rv;
@@ -2934,7 +2929,6 @@ kz_gecko_embed_create_thumbnail (KzEmbed *kzembed, EggPixbufThumbSize size)
 	wrapper->CreateThumbnail(uri, last_modified, size);
 #else
 
-	nsresult rv;
 	GdkDrawable *window;
 	gint width, height;
 	GdkPixbuf *pixbuf, *thumbnail;
@@ -3202,7 +3196,6 @@ kz_gecko_embed_get_last_modified (KzEmbed *kzembed)
 
 	doc->GetLastModified(value);
 
-	guint mod_time = 0;
 	nsEmbedCString cValue;
 	NS_UTF16ToCString(value,
 			  NS_CSTRING_ENCODING_UTF8, cValue);
