@@ -83,7 +83,7 @@ static void set_user_agent (KzProfile *profile);
 
 static KzGeckoSingle    *the_kz_gecko_single = NULL;
 
-G_DEFINE_TYPE(KzGeckoSingle, kz_gecko_single, GTK_TYPE_MOZ_EMBED_SINGLE)
+G_DEFINE_TYPE(KzGeckoSingle, kz_gecko_single, G_TYPE_OBJECT)
 
 static void
 kz_gecko_single_class_init (KzGeckoSingleClass *klass)
@@ -226,7 +226,6 @@ kz_gecko_single_new (KzApp *kz_app)
 static gchar *
 convert_preference_name (const gchar *prefix, const gchar *key)
 {
-	gint i = 0;
 	gchar *ret;
 
 	ret = g_strdup_printf("%s.%s", prefix, key);
@@ -423,8 +422,6 @@ cb_privacy_profile_changed (KzProfile *profile,
 			    const gchar *old_value,
 			    gpointer data)
 {
-	gchar *converted_key;
-
 	switch (key[0])
 	{
 	case 'c':// cookie
