@@ -93,6 +93,7 @@
 #include <nsIDOM3Document.h>
 #include <nsIDocCharset.h>
 
+
 #ifdef HAVE_NSIPRESCONTEXT_H
 #  include <nsIPresContext.h>
 #else
@@ -109,6 +110,7 @@ typedef nsCString             nsAFlatCString;
 #include "kz-mozutils.h"
 #include "utils.h"
 #include "kz-bookmark.h"
+#include "kz-mozthumbnailer.h"
 
 # include <nsISSLStatus.h>
 # include <nsISSLStatusProvider.h>
@@ -570,7 +572,8 @@ KzMozWrapper::GetWebNavigation (nsIWebNavigation **aWebNavigation)
 	rv = docView->GetDefaultView(getter_AddRefs(abstractView));
 	if (NS_FAILED(rv) || !abstractView) return NS_ERROR_FAILURE;
 
-	nsCOMPtr<nsIWebNavigation> wn = do_QueryInterface(abstractView, &rv);
+	nsCOMPtr<nsIWebNavigation> wn (do_GetInterface (abstractView, &rv));
+
 	if (NS_FAILED(rv) || !wn) return NS_ERROR_FAILURE;
 
 	NS_IF_ADDREF(*aWebNavigation = wn);
@@ -929,7 +932,6 @@ KzMozWrapper::SetHTMLHeadSource (nsIDOMDocument *domDocument,
 {
 	const PRUnichar dq[] = { '"', '\0' };
 	const PRUnichar sp[] = { ' ', '\0' };
-	const PRUnichar sl[] = { '/', '\0' };
 	const PRUnichar lt[] = { '<', '\0' };
 	const PRUnichar gt[] = { '>', '\0' };
 	const PRUnichar cr[] = { '\n', '\0' };
@@ -1435,12 +1437,12 @@ KzMozWrapper::PrintPreview (void)
 nsresult
 KzMozWrapper::GetPrinterList (GList **list)
 {
-	GList *printers = NULL;
-	nsresult rv = NS_OK;
 
 #ifndef HAVE_NSIPRINTOPTIONS_AVAILABLEPRINTERS
 	*list = NULL;
 #else
+	GList *printers = NULL;
+	nsresult rv = NS_OK;
 	nsCOMPtr<nsIPrintSettingsService> pss =
 		do_GetService("@mozilla.org/gfx/printsettings-service;1", &rv);
 	NS_ENSURE_SUCCESS(rv, nsnull);
@@ -1860,21 +1862,12 @@ KzMozWrapper::GetPostData (nsIHistoryEntry *he, nsAString &postData)
 
 	if (!iStream || NS_FAILED(rv)) return NS_ERROR_FAILURE;
 
-	char *aBuf;
-	PRUint32 aCount;
-	PRUint32 ret;
-
-	rv = iStream->Read(aBuf, 1024, &ret);
-
-	g_warning("%s", aBuf);	
-
 	return rv;
 }	
 
 nsresult
 KzMozWrapper::SetPostData (nsIHistoryEntry *he, const nsAString &postData)
 {
-	nsresult rv;
 #if 0
 	nsCOMPtr<nsISHEntry> she = do_QueryInterface (he);
 
@@ -1885,7 +1878,7 @@ KzMozWrapper::SetPostData (nsIHistoryEntry *he, const nsAString &postData)
 
 	rv = she->SetPostData(iStream);
 #endif
-	return rv;
+	return NS_OK;
 }
 
 // this function is picked from galeon-1.3.18
@@ -2100,8 +2093,8 @@ KzMozWrapper::CreateThumbnail (const gchar *uri,
 	nsCOMPtr<nsIDOMWindow> domWindow;
 	GetDOMWindow(getter_AddRefs(domWindow));
 
-// 	if (!MozillaPrivate::CreateThumbnail(domWindow, uri,
-// 					     last_modified, size))
+ 	if (!KzMozThumbnailer::CreateThumbnail(domWindow, uri,
+					       last_modified, size))
 		return NS_ERROR_FAILURE;
 
 	return NS_OK;
