@@ -268,7 +268,7 @@ create_search_result_html (KzSearch *search, const gchar *text)
 	int *results, n_results, i;
 	gchar *except_word, *tmp;
 	gchar **texts;
-	GString *html, *phrase;
+	GString *html, *phrase, *desc_str;
 	gint num_summary = 128, max_results = 20, half_of_summary;
 	KzHyperEstraierSearch *he_search;
 
@@ -280,16 +280,16 @@ create_search_result_html (KzSearch *search, const gchar *text)
 
 	cond = est_cond_new();
 	texts = g_strsplit(text, " ", -1);
-	tmp = g_strjoinv(" " ESTOPISECT " ", texts);
 
 	highlights = cblistopen();
 	for (i = 0; texts[i]; i++)
 	{
 		cblistpush(highlights, texts[i], -1);
 	}
-
+	tmp = g_strjoinv(" " ESTOPISECT " ", texts);
 	g_strfreev(texts);
 	phrase = g_string_new(tmp);
+	g_free(tmp);
 
 	except_word = KZ_CONF_GET_STR("History", "except_keyword");
 	if (except_word && *except_word)
@@ -314,70 +314,94 @@ create_search_result_html (KzSearch *search, const gchar *text)
 
 	results = est_mtdb_search(he_search->db, cond, &n_results, NULL);
 
-	html = g_string_sized_new(0);
+	desc_str = g_string_sized_new(num_summary*2 - 1);		/* almost typical in num_summary*2 */
+	html = g_string_sized_new((num_summary*2+512)*max_results);	/* typical in num_summary*2*max_results */
 
 	g_string_append(html, DTD"\n");
 	g_string_append(html, "<html>\n");
 	g_string_append(html, HEAD);
 	g_string_append(html, "<body>\n");
 
-	g_string_append_printf(html, "<h1>Search results for %s</h1>",
-			       text);
+	g_string_append_printf(html, "<h1>Search results for %s</h1>\n", text);
 
 	for (i = 0; i < MIN(n_results, max_results); i++)
 	{
 		ESTDOC *doc;
-		const gchar *title, *uri, *date;
-		gchar *desc, *cache_str = NULL;
-		const gchar *cache_link, *thumb_uri, *thumb_filename;
+		const gchar *title, *date, *cache_link;
+		gchar *cache_str, *thumb_filename, *uri, *thumb_uri;
+		gchar *desc, **desc_highlight;
+		guint desc_len, desc_i;
 
 		doc = est_mtdb_get_doc(he_search->db, results[i], 0);
 		if (!doc)
 			continue;
 
 		cache_link = est_doc_attr(doc, ESTDATTRURI);
-		uri = create_uri_from_filename(cache_link +
-					       strlen("file://") +
-					       he_search->cache_path_len +
-					       strlen(G_DIR_SEPARATOR_S));
-		thumb_filename =
-			egg_pixbuf_get_thumb_filename(uri,
-						      EGG_PIXBUF_THUMB_LARGE);
-		thumb_uri = g_strdup_printf("history-search:?image=%s",
-					    thumb_filename);
-		title = est_doc_attr(doc, ESTDATTRTITLE);
-		date = est_doc_attr(doc, ESTDATTRMDATE);
-
-		desc = est_doc_make_snippet(doc, highlights, num_summary,
-					    half_of_summary, half_of_summary);
-
 		if (g_file_test(cache_link+strlen("file://"), G_FILE_TEST_EXISTS))
 		{
 			gchar *escaped_cache_link;
-			escaped_cache_link =
-				kz_uri_encode_last_component(cache_link);
-			cache_str = g_strdup_printf("<span class=\"cache\"><a href=\"%s\">cache</a></span>\n", escaped_cache_link);
+			escaped_cache_link = kz_uri_encode_last_component(cache_link);
+			cache_str = g_strdup_printf("<span class=\"cache\"><a href=\"%s\">cache</a>"
+			                            "</span>\n", escaped_cache_link);
 			g_free(escaped_cache_link);
 		}
 		else
 		{
 			cache_str = g_strdup("");
-		}
+		}		
+		uri = create_uri_from_filename(cache_link +
+					       strlen("file://") +
+					       he_search->cache_path_len +
+					       strlen(G_DIR_SEPARATOR_S));
 
+		thumb_filename =
+			egg_pixbuf_get_thumb_filename(uri,
+						      EGG_PIXBUF_THUMB_LARGE);
+		thumb_uri = g_strdup_printf("history-search:?image=%s",
+					    thumb_filename);
+		g_free(thumb_filename);
+
+		title = est_doc_attr(doc, ESTDATTRTITLE);
+		if(!title || !*title) title = "[NO TITLE]";
+		date = est_doc_attr(doc, ESTDATTRMDATE);
+
+		desc = est_doc_make_snippet(doc, highlights, num_summary,
+					    half_of_summary, half_of_summary);
+		/* make highlight keyword */
+		//TODO:more fast that don't split
+		desc_highlight = g_strsplit_set(desc, "\n", 0);
+		free(desc);		/* don't g_free because born from estraier func */
+		desc_len = g_strv_length(desc_highlight);
+		desc_str->len = 0;	/* reset contain length */
+		for(desc_i = 0; desc_i < desc_len; desc_i++) {
+		    char *found = strchr(desc_highlight[desc_i], '\t');
+		    if (found) {
+			*found = '\0';
+			g_string_append(desc_str, "<b>");
+			g_string_append(desc_str, desc_highlight[desc_i]);
+			g_string_append(desc_str, "</b>");
+		    } else {
+			g_string_append(desc_str, desc_highlight[desc_i]);
+		    }
+		}
+		g_strfreev(desc_highlight);
+		
 		g_string_append_printf(html,
 				       CONTENT,
 				       uri,
 				       title,
 				       thumb_uri, /* thumbnail */
-				       desc,
+				       desc_str->str,
 				       uri,
 				       cache_str,
 				       date);
+		g_free(uri);
 		g_free(cache_str);
-		g_free(desc);
+		g_free(thumb_uri);
 		est_doc_delete(doc);
 	}
 	free(results);
+	g_string_free(desc_str, TRUE);
 
 	cblistclose(highlights);
 	est_cond_delete(cond);
@@ -436,11 +460,93 @@ get_document_encoding (const gchar *contents)
 	return encoding;
 }
 
+
+/* Type and functions that used in gMmarkupParser */
+/* drop at the tiem 
+typedef struct {
+	gint in_title;
+	gchar *title;
+} title_parsing;
+static void title_start_element(GMarkupParseContext *context, const gchar *element_name,
+			 const gchar **attribute_names, const gchar **attribute_values,
+			 gpointer user_data, GError **error)
+{
+	gchar *tag = g_utf8_strup(element_name, -1);
+//	printf("what elem:%s\n", tag);
+	if(g_strcmp(tag, "TITLE") == 0) {
+	    ((title_parsing *) user_data)->in_title = 1;
+	} else if(g_strcmp(tag, "BODY") == 0) {
+	    g_markup_parse_context_end_parse(context, error);
+	}
+	g_free(tag);
+}
+static void title_end_element(GMarkupParseContext *context, const gchar         *element_name,
+                       gpointer             user_data, GError             **error)
+{
+	gchar *tag = g_utf8_strup(element_name, -1);
+	if(g_strcmp(tag, "META") == 0) {
+		g_markup_parse_context_end_parse(context, error);
+	}
+	g_free(tag);
+}
+static void title_text(GMarkupParseContext *context, const gchar *text,
+                gsize text_len, gpointer user_data, GError **error)
+{
+	if(((title_parsing *) user_data)->in_title != 0) {
+		((title_parsing *) user_data)->title = g_strndup(text, text_len);
+		printf("title get in func:%s\n", ((title_parsing *) user_data)->title);
+		g_markup_parse_context_end_parse(context, error);
+		((title_parsing *) user_data)->in_title = 0;
+	}
+}
+drop at the time */
+/**
+ * create page title from html content string
+ * currentlly called from only register_documents_in_path.
+ * @parm contents utf-8 strings that contain html contents
+ * @return gchar* new allocated, should be g_free or NULL for failed parsing
+ */
+static gchar *
+get_document_title(const gchar *contents)
+{
+	/* didn't work yet.
+	GMarkupParser title_parser_funcs = {
+		title_start_element, title_end_element,
+		title_text, NULL, NULL
+	};
+	title_parsing data = {0, NULL};
+	GMarkupParseContext *title_parser;
+	
+	title_parser = g_markup_parse_context_new(&title_parser_funcs,
+						  0,
+						  &data,
+						  NULL);
+	if(!title_parser) {
+	    printf("parser create fail.\n");
+	    return NULL;
+	}
+	g_markup_parse_context_parse(title_parser, contents, 1024, NULL);
+	g_markup_parse_context_free(title_parser);
+	printf("get title:%s\n", data.title);
+	return data.title;
+	
+	*/ 
+	/* simple parser */
+	//FIXME: parse correctly
+	gchar *start;
+	start = strcasestr(contents, "<title>");
+	if(start == NULL) {
+	    //printf("not in title.\n");
+	    return NULL;
+	}
+	start += strlen("<title>");
+	return g_strndup(start, strstr(start, "<") - start);
+}
+
 gboolean
 register_document (KzSearch *search, const gchar *uri, const gchar *title, const gchar *contents, GTime mtime)
 {
 	ESTDOC *doc;
-	int ecode;
 	gboolean success;
 	gchar *time_str, *filename, *text = NULL;
 	gchar *tmp_filename, *tmp_path;
@@ -479,8 +585,17 @@ register_document (KzSearch *search, const gchar *uri, const gchar *title, const
 	}
 
 	success = est_mtdb_put_doc(he_search->db, doc, ESTPDCLEAN) != 0;
-	if (!success)
-		g_warning("register error: %s", est_err_msg(ecode));
+	if (!success) {
+		g_warning("register error: %s", est_err_msg(est_mtdb_error(he_search->db)));
+		g_warning("retry...");
+		est_mtdb_sync(he_search->db);
+		if(est_mtdb_put_doc(he_search->db, doc, 0)) {
+		    g_warning("succeed!");
+		} else {
+		    g_warning("register error: %s", est_err_msg(est_mtdb_error(he_search->db)));
+		    g_warning("drop %s,%s\n", ESTDATTRURI, est_doc_attr(doc, ESTDATTRURI));
+		} 
+	}
 
 	est_doc_delete(doc);
 
@@ -533,6 +648,14 @@ get_search_result_bookmark (KzSearch *search, const gchar *text)
 	return NULL;
 }
 
+/**
+ * register all documents in given path
+ * @parm search this search class
+ * @parm path path to the directory contains contents to register
+ * @return void
+ */
+//TODO:don't register image type
+//TODO:correct parse title (get_document_title())
 static void
 register_documents_in_path (KzSearch *search, const gchar *path)
 {
@@ -565,8 +688,6 @@ register_documents_in_path (KzSearch *search, const gchar *path)
 			uri = create_uri_from_filename(new_path +
 						       he_search->cache_path_len +
 						       1);
-			title = uri;
-
 			encoding = get_document_encoding(contents);
 			if (!encoding)
 				encoding = g_strdup(est_enc_name(contents,
@@ -580,23 +701,37 @@ register_documents_in_path (KzSearch *search, const gchar *path)
 							  "UTF-8", encoding,
 							  NULL, NULL,
 							  NULL);
+
 				if (utf8_contents)
 				{
-					kz_search_register_document(search,
+					title = get_document_title(utf8_contents);
+					if(!title) {
+						// printf("fail title in %s\n", uri);
+						title = g_strdup(uri);
+					}
+					register_document(search,
 								    uri,
 								    title,
 								    utf8_contents,
 								    mtime);
 					g_free(utf8_contents);
+					g_free(title);
 				}
 			}
-			else
-				kz_search_register_document(search, uri, title,
+			else {
+				title = get_document_title(contents);
+				if(!title) {
+					// printf("fail title in %s\n", uri);
+					title = g_strdup(uri);
+				}
+				register_document(search, uri, title,
 							    contents, mtime);
- 
+				g_free(title);
+			}
  			if (encoding)
 				g_free(encoding);
 			g_free(uri);
+
 			g_free(contents);
 		}
 		g_free(new_path);
