@@ -20,9 +20,15 @@
  */
 
 #include "kz-embed-event.h"
+#include "gobject-utils.h"
+
+KZ_BOXED_GET_TYPE(kz_embed_event_key, "KzEmbedEventKey",
+		  kz_embed_event_copy, kz_embed_event_free)
+KZ_BOXED_GET_TYPE(kz_embed_event_mouse, "KzEmbedEventMouse",
+		  kz_embed_event_copy, kz_embed_event_free)
 
 KzEmbedEvent *
-kz_embed_event_new  (KzEmbedEventType type)
+kz_embed_event_new (KzEmbedEventType type)
 {
 	KzEmbedEvent *event;
 
@@ -49,21 +55,58 @@ kz_embed_event_new  (KzEmbedEventType type)
 }
 
 
+KzEmbedEvent *
+kz_embed_event_copy (KzEmbedEvent *event)
+{
+	KzEmbedEvent *newevent;
+
+	g_return_val_if_fail(event, NULL);
+
+	newevent = kz_embed_event_new(event->type);
+	switch (event->type) {
+	case KZ_EMBED_EVENT_KEY:
+		*((KzEmbedEventKey*)newevent) = *((KzEmbedEventKey*)event);
+		break;
+	case KZ_EMBED_EVENT_MOUSE:
+		*((KzEmbedEventMouse*)newevent) = *((KzEmbedEventMouse*)event);
+		break;
+	default:
+		g_warning("invalid event type: %d\n", event->type);
+		kz_embed_event_free(event);
+		return NULL;
+	}
+
+	if (event->link)
+		newevent->link = g_strdup(event->link);
+	if (event->linktext)
+		newevent->linktext = g_strdup(event->linktext);
+	if (event->img)
+		newevent->img = g_strdup(event->img);
+	if (event->frame_src)
+		newevent->frame_src = g_strdup(event->frame_src);
+
+	return newevent;
+}
+
+
 void
 kz_embed_event_free (KzEmbedEvent *event)
 {
-	g_free(event->link);
+	if (event->link)
+		g_free(event->link);
 	event->link = NULL;
 
-	g_free(event->linktext);
+	if (event->linktext)
+		g_free(event->linktext);
 	event->linktext = NULL;
 
-	g_free(event->img);
+	if (event->img)
+		g_free(event->img);
 	event->img = NULL;
 
-	if(event->frame_src)
+	if (event->frame_src)
 		g_free(event->frame_src);
-	event->img = NULL;
+	event->frame_src = NULL;
 
 	event->element = NULL;
 
