@@ -24,6 +24,7 @@
 #include "kz-marshalers.h"
 
 static GList *embeds = NULL;
+static gboolean loaded = FALSE;
 
 static const gchar *
 _kz_embed_module_dir (void)
@@ -32,16 +33,28 @@ _kz_embed_module_dir (void)
         base_dir = g_getenv("KZ_EMBED_MODULE_DIR");
 	if (base_dir)
 		return base_dir;
-        return KZ_EMBED_MODULEDIR;
+        return KZ_GET_SYSTEM_EMBED_MODULE_DIR;
 }
 
 void
 kz_embed_load (const gchar *base_dir)
 {
+	GList *loaded_modules;
+	gboolean local_loaded = loaded;
+
+	loaded = TRUE;
+
 	if (!base_dir)
 		base_dir = _kz_embed_module_dir();
 
-	embeds = g_list_concat(kz_module_load_modules(base_dir), embeds);
+	if (local_loaded)
+		loaded_modules = kz_module_load_modules(base_dir);
+	else
+		loaded_modules = kz_module_load_modules_unique(base_dir, embeds);
+
+#warning FIXME: workaround for kz-gecko-embed.cpp.
+	g_list_foreach(loaded_modules, (GFunc)g_type_module_use, NULL);
+	embeds = g_list_concat(loaded_modules, embeds);
 }
 
 void
@@ -61,7 +74,7 @@ kz_embed_exit (void)
 }
 
 GList *
-kz_embed_engine_names(void)
+kz_embed_engine_names (void)
 {
 	GList *node;
 	GList *result = NULL;
@@ -76,6 +89,25 @@ kz_embed_engine_names(void)
 	return result;
 }
 
+GList *
+kz_embed_engine_ids (void)
+{
+	GList *node;
+	GList *result = NULL;
+
+	if (!loaded)
+		kz_embed_load(NULL);
+
+	for (node = embeds; node; node = g_list_next(node))
+	{
+		KzModule *module = node->data;
+		result = g_list_append(result,
+				       g_strdup(G_TYPE_MODULE(module)->name));
+	}
+
+	return result;
+}
+
 static GtkWidget *
 _kz_embed_new (KzModule *module, const gchar *name,
 	       const gchar *first_property, ...)
@@ -361,7 +393,18 @@ kz_embed_load_url (KzEmbed *kzembed, const gchar *url)
 {
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
 
-	KZ_EMBED_GET_IFACE(kzembed)->load_url(kzembed, url);
+	if (kz_embed_get_lock(kzembed))
+	{
+		KzEmbed *newembed = NULL;
+		g_signal_emit_by_name(kzembed, 
+				      "new-window",
+				      &newembed, 0);
+		KZ_EMBED_GET_IFACE(kzembed)->load_url(newembed, url);
+	}
+	else
+	{
+		KZ_EMBED_GET_IFACE(kzembed)->load_url(kzembed, url);
+	}
 }
 
 
@@ -944,12 +987,12 @@ kz_embed_get_printer_list (KzEmbed *kzembed)
 
 
 void
-kz_embed_create_thumbnail (KzEmbed *kzembed)
+kz_embed_create_thumbnail (KzEmbed *kzembed, EggPixbufThumbSize size)
 {
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
-	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->create_thumbnail);
 
-	KZ_EMBED_GET_IFACE(kzembed)->create_thumbnail(kzembed);
+	if (KZ_EMBED_GET_IFACE(kzembed)->create_thumbnail)
+		KZ_EMBED_GET_IFACE(kzembed)->create_thumbnail(kzembed, size);
 }
 
 
@@ -1044,9 +1087,8 @@ void
 kz_embed_set_history (KzEmbed *kzembed, KzBookmark *history)
 {
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
-	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->set_history);
-
-	KZ_EMBED_GET_IFACE(kzembed)->set_history(kzembed, history);
+	if (KZ_EMBED_GET_IFACE(kzembed)->set_history)
+		KZ_EMBED_GET_IFACE(kzembed)->set_history(kzembed, history);
 }
 
 
@@ -1054,9 +1096,9 @@ void
 kz_embed_get_history (KzEmbed *kzembed, KzBookmark *history)
 {
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
-	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->get_history);
-
-	KZ_EMBED_GET_IFACE(kzembed)->get_history(kzembed, history);
+	
+	if (KZ_EMBED_GET_IFACE(kzembed)->get_history)
+		KZ_EMBED_GET_IFACE(kzembed)->get_history(kzembed, history);
 }
 
 
