@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.c 3352 2008-01-09 12:42:30Z furyo $
+ *  $Id: kz-xml.c 3408 2008-02-27 11:02:13Z ikezoe $
  */
 
 #include "kz-xml.h"
@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
+#include "utils.h"
 
 typedef struct _KzXMLPrivate    KzXMLPrivate;
 struct _KzXMLPrivate
@@ -315,6 +316,7 @@ kz_xml_save (KzXML *xml, const gchar *filename)
 	FILE *fp;
 	const gchar *file = filename ? filename : xml->file;
 	gchar *str;
+	size_t len;
 
 	g_return_val_if_fail(file && *file, FALSE);
 
@@ -330,7 +332,7 @@ kz_xml_save (KzXML *xml, const gchar *filename)
 		return FALSE;
 	}
 
-	fwrite(str, strlen(str), 1, fp);
+	len = fwrite(str, strlen(str), 1, fp);
 	fclose(fp);
 	g_free(str);
 
