@@ -28,7 +28,14 @@
 #ifndef _GNET_H
 #define _GNET_H
 
+#ifdef __CYGWIN__
+#  define __USE_W32_SOCKETS
+#endif
+
 #include <glib.h>
+#ifdef G_OS_WIN32
+#  define GNET_WIN32
+#endif
 
 #include "inetaddr.h"
 #include "tcp.h"
