@@ -40,20 +40,20 @@ static void           prefs_new_tab_response    (GtkWidget *widget,
 
 static KzPrefsWinPageEntry prefs_entry =
 {
-	path:            N_("/Tab"),
-	priority_hint:   0,
-	ui_level:        ~KZ_UI_LEVEL_BEGINNER,
-	create:          prefs_tab_create,
-	response:        prefs_tab_response,
+	/* .path          = */ N_("/Tab"),
+	/* .priority_hint = */ 0,
+	/* .ui_level      = */ ~KZ_UI_LEVEL_BEGINNER,
+	/* .create        = */ prefs_tab_create,
+	/* .response      = */ prefs_tab_response,
 };
 
 static KzPrefsWinPageEntry prefs_new_tab_entry =
 {
-	path:            N_("/Tab/New tab"),
-	priority_hint:   0,
-	ui_level:        ~KZ_UI_LEVEL_BEGINNER,
-	create:          prefs_new_tab_create,
-	response:        prefs_new_tab_response,
+	/* .path          = */ N_("/Tab/New tab"),
+	/* .priority_hint = */ 0,
+	/* .ui_level      = */ ~KZ_UI_LEVEL_BEGINNER,
+	/* .create        = */ prefs_new_tab_create,
+	/* .response      = */ prefs_new_tab_response,
 };
 
 
